#ifndef WINDB_H
#define WINDB_H

#include <gtk/gtk.h>
#include "win.h"


extern void WinDBUpdate(
	win_struct *win, const gchar *db_location,
	const gboolean verbose
);
extern void WinDBQueueUpdate(win_struct *win);
extern void WinDBClear(win_struct *win);


#endif	/* WINDB_H */
